package cygx

import (
	"encoding/json"
	"github.com/rdlucklib/rdluck_tools/paging"
	"hongze/hz_crm_api/controllers"
	"hongze/hz_crm_api/models"
	"hongze/hz_crm_api/models/cygx"
	"hongze/hz_crm_api/utils"
	"strconv"
	"time"
)

// 产品内测
type OrderController struct {
	controllers.BaseAuthController
}

// @Title 列表
// @Description 列表接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   StartDate   query   string  false       "开始时间 ，列如2021-03-06 "
// @Param   EndDate   query   string  false       "结束时间，列如2021-03-06 "
// @Param   AdminId   query   string  false       "销售ID "
// @Param   OrderType   query   int  false       "订单类型 1：畅读卡订单，2：单场付费订单"
// @Param   PaymentProject   query   string  false       "付款项目"
// @Param   OrderCode   query   string  false       "订单编号"
// @Param   KeyWord   query   string  false       "搜索关键词"
// @Success Ret=200 {object} cygx.GetCygxTacticsTimeLineResp
// @router /order/list [get]
func (this *OrderController) OrderList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}
	resp := new(cygx.UserOrderListResp)
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	orderType, _ := this.GetInt("OrderType", 1)
	startDate := this.GetString("StartDate")
	endDate := this.GetString("EndDate")
	adminId := this.GetString("AdminId")
	orderCode := this.GetString("OrderCode")
	keyWord := this.GetString("KeyWord")
	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = utils.StartIndex(currentIndex, pageSize)
	var condition string
	var pars []interface{}

	if orderType > 0 { //订单类型 1：畅读卡订单，2：单场付费订单
		condition += `  AND order_type =   ? `
		pars = append(pars, orderType)
	}

	if startDate != "" && endDate != "" { //时间范围
		condition += ` 	AND create_time  BETWEEN ?   AND  ? `
		pars = append(pars, startDate, endDate)
	}

	if adminId != "" { //所属销售筛选
		condition += ` 	AND seller_id IN (` + adminId + `) `
	}

	if orderCode != "" { //订单编号
		orderCode = "%" + orderCode + "%"
		condition += ` 	AND order_code LIKE ? `
		pars = append(pars, orderCode)
	}

	if keyWord != "" { //用户姓名，手机号
		keyWord = "%" + keyWord + "%"
		condition += ` 	AND (mobile LIKE ?  OR  real_name LIKE ? ) `
		pars = append(pars, keyWord, keyWord)
	}

	total, err := cygx.GetCygxOrderCount(condition, pars)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}
	condition += "	ORDER BY order_id  DESC "
	list, err := cygx.GetCygxOrderList(condition, pars, startSize, pageSize)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}

	for _, v := range list {
		item := new(cygx.OrderListResp)
		item.OrderCode = v.OrderCode
		item.OrderMoney = v.OrderMoney
		item.SourceId = v.SourceId
		item.Source = v.Source
		item.SourceTitle = v.SourceTitle
		switch v.Source {
		case "article": //文章详情
			item.HttpUrl = utils.CYGX_WEB_URL + "/material/info/" + strconv.Itoa(v.SourceId)
		case "activity": //活动详情
			item.HttpUrl = utils.CYGX_WEB_URL + "/activity/detail/" + strconv.Itoa(v.SourceId)
		}
		item.OrderStatus = v.OrderStatus
		if v.OrderStatus == 0 {
			item.OrderStatusText = "已取消"
		} else if v.OrderStatus == 1 {
			item.OrderStatusText = "待支付"
		} else if v.OrderStatus == 2 {
			item.OrderStatusText = "已支付"
		}
		item.UserId = v.UserId
		item.RealName = v.RealName
		item.Mobile = v.Mobile
		item.Email = v.Email
		item.CompanyId = v.CompanyId
		item.CompanyName = v.CompanyName
		item.SellerName = v.SellerName
		item.InviteName = "推荐人"
		item.PaymentProject = v.GoodsName

		if v.OrderStatus == 2 {
			item.PayTime = v.PayTime.Format(utils.FormatDateTime)
		}
		if orderType == 1 {
			item.StartDate = time.Now().Format(utils.FormatDateTime)
			item.EndDate = time.Now().AddDate(0, 0, 3).Format(utils.FormatDateTime)
		}
		item.CreateTime = v.CreateTime.Format(utils.FormatDateTime)
		resp.List = append(resp.List, item)
	}

	page := paging.GetPaging(currentIndex, pageSize, total)
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 退款
// @Description 退款接口
// @Param	request	body cygx.UserRemarAddReq true "type json string"
// @Success 200 操作成功
// @router /order/refund [post]
func (this *UserController) OrderRefund() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}
	var req cygx.CygxOrderRefundReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}
	orderCode := req.OrderCode
	remark := req.Remark

	if remark == "" {
		br.Msg = "请填写退款原因"
		return
	}
	orderDetail, err := cygx.GetCygxOrderDetailByOrderCode(orderCode)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败, Err:" + err.Error()
		return
	}
	if orderDetail.OrderStatus != 2 {
		br.Msg = "订单状态异常！"
		br.ErrMsg = "订单状态异常，orderCode:" + orderCode
		return
	}
	item := new(cygx.CygxOrderRefund)
	item.OrderCode = orderCode
	item.RefundMoney = orderDetail.OrderMoney
	item.RefundWay = 1
	item.Remark = remark
	item.CreateTime = time.Now()
	item.RefundTime = time.Now()
	item.AdminId = sysUser.AdminId
	item.AdminName = sysUser.RealName
	err = cygx.AddCygxOrderRefund(item)
	if err != nil {
		br.Msg = "新增失败."
		br.ErrMsg = "新增失败,Err:" + err.Error()
		return
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "新增成功"
}

// @Title 退款记录列表
// @Description 退款记录列表接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   StartDate   query   string  false       "开始时间 ，列如2021-03-06 "
// @Param   EndDate   query   string  false       "结束时间，列如2021-03-06 "
// @Param   AdminId   query   string  false       "销售ID "
// @Param   OrderType   query   int  false       "订单类型 1：畅读卡订单，2：单场付费订单"
// @Param   PaymentProject   query   string  false       "付款项目"
// @Param   OrderCode   query   string  false       "订单编号"
// @Param   KeyWord   query   string  false       "搜索关键词"
// @Success Ret=200 {object} cygx.GetCygxTacticsTimeLineResp
// @router /order/refund/list [get]
func (this *OrderController) OrderRefundList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}
	resp := new(cygx.UserOrderListResp)
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	orderType, _ := this.GetInt("OrderType", 1)
	startDate := this.GetString("StartDate")
	endDate := this.GetString("EndDate")
	adminId := this.GetString("AdminId")
	orderCode := this.GetString("OrderCode")
	keyWord := this.GetString("KeyWord")
	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = utils.StartIndex(currentIndex, pageSize)
	var condition string
	var pars []interface{}
	condition += `  AND order_status =   3 `
	if orderType > 0 { //订单类型 1：畅读卡订单，2：单场付费订单
		condition += `  AND order_type =   ? `
		pars = append(pars, orderType)
	}

	if startDate != "" && endDate != "" { //时间范围
		condition += ` 	AND create_time  BETWEEN ?   AND  ? `
		pars = append(pars, startDate, endDate)
	}

	if adminId != "" { //所属销售筛选
		condition += ` 	AND seller_id IN (` + adminId + `) `
	}

	if orderCode != "" { //订单编号
		orderCode = "%" + orderCode + "%"
		condition += ` 	AND order_code LIKE ? `
		pars = append(pars, orderCode)
	}

	if keyWord != "" { //用户姓名，手机号
		keyWord = "%" + keyWord + "%"
		condition += ` 	AND (mobile LIKE ?  OR  real_name LIKE ? ) `
		pars = append(pars, keyWord, keyWord)
	}

	total, err := cygx.GetCygxOrderCount(condition, pars)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}
	condition += "	ORDER BY order_id  DESC "
	list, err := cygx.GetCygxOrderList(condition, pars, startSize, pageSize)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}

	for _, v := range list {
		item := new(cygx.OrderListResp)
		item.OrderCode = v.OrderCode
		item.OrderMoney = v.OrderMoney
		item.SourceId = v.SourceId
		item.Source = v.Source
		item.SourceTitle = v.SourceTitle
		switch v.Source {
		case "article": //文章详情
			item.HttpUrl = utils.CYGX_WEB_URL + "/material/info/" + strconv.Itoa(v.SourceId)
		case "activity": //活动详情
			item.HttpUrl = utils.CYGX_WEB_URL + "/activity/detail/" + strconv.Itoa(v.SourceId)
		}
		item.OrderStatus = v.OrderStatus
		if v.OrderStatus == 3 {
			item.OrderStatusText = "退款成功"
		} else {
			item.OrderStatusText = "退款异常"
		}
		item.UserId = v.UserId
		item.RealName = v.RealName
		item.Mobile = v.Mobile
		item.Email = v.Email
		item.CompanyId = v.CompanyId
		item.CompanyName = v.CompanyName
		item.SellerName = v.SellerName
		item.InviteName = "推荐人"
		item.PaymentProject = v.GoodsName
		item.RefundTime = v.RefundTime.Format(utils.FormatDateTime)
		item.RefundRemark = v.RefundRemark

		if v.OrderStatus == 2 {
			item.PayTime = v.PayTime.Format(utils.FormatDateTime)
		}
		if orderType == 1 {
			item.StartDate = time.Now().Format(utils.FormatDateTime)
			item.EndDate = time.Now().AddDate(0, 0, 3).Format(utils.FormatDateTime)
		}
		item.CreateTime = v.CreateTime.Format(utils.FormatDateTime)
		resp.List = append(resp.List, item)
	}

	page := paging.GetPaging(currentIndex, pageSize, total)
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}
